@@ -176,11 +176,16 @@ impl Build {
             configure.arg("no-seed");
         }
 
-        if target.contains("musl") || target.contains("windows") {
+        if target.contains("musl") {
             // This actually fails to compile on musl (it needs linux/version.h
             // right now) but we don't actually need this most of the time.
-            // API of engine.c ld fail in Windows.
             configure.arg("no-engine");
+        } else if target.contains("windows") {
+            // We can build the engine feature, but the build doesn't seem
+            // to correctly pick up crypt32.lib functions such as
+            // `__imp_CertOpenStore` when building the capieng engine.
+            // Let's disable just capieng.
+            configure.arg("no-capieng");
         }
 
         if target.contains("musl") {
@@ -268,6 +273,7 @@ impl Build {
             "riscv64gc-unknown-linux-gnu" => "linux-generic64",
             "s390x-unknown-linux-gnu" => "linux64-s390x",
             "s390x-unknown-linux-musl" => "linux64-s390x",
+            "sparcv9-sun-solaris" => "solaris64-sparcv9-gcc",
             "thumbv7a-uwp-windows-msvc" => "VC-WIN32-ARM-UWP",
             "x86_64-apple-darwin" => "darwin64-x86_64-cc",
             "x86_64-linux-android" => "linux-x86_64",
